@@ -210,13 +210,10 @@ def score_embeddings(
         typer.echo("Error: No length results found in .pt file.")
         raise typer.Exit(code=1)
     
-    final_scores_per_length = {}
+    length_scores = {}
+    all_individual_scores = []
     for target_length, raw in length_results.items():
         sample_results = raw.get('sample_results', [])
-        if not sample_results:
-            final_scores_per_length[target_length] = 0.0
-            continue
-            
         sample_scores = []
         for sample_dict in sample_results:
             probe_embeddings = sample_dict.get('chunk_embeddings')
@@ -234,24 +231,20 @@ def score_embeddings(
             else:
                 sample_scores.append(0.0)
 
-        # Average the scores of all samples for this length
-        avg_length_score = np.mean(sample_scores) if sample_scores else 0.0
-        final_scores_per_length[target_length] = avg_length_score * 500 # Scale after averaging
+        # Store scaled and rounded individual scores as list
+        scaled_scores = [round(score * 500, 6) for score in sample_scores]
+        length_scores[target_length] = scaled_scores
+        all_individual_scores.extend(scaled_scores)
 
-    avg_rss = np.mean(list(final_scores_per_length.values()))
-    
-    # Round scores for precision control (get_content_hash will convert to str)
+    # Average RSS is mean of all individual scaled scores
+    avg_rss = np.mean(all_individual_scores) if all_individual_scores else 0.0
     avg_rss = round(avg_rss, 6)
-    rounded_length_scores = {
-        length: round(score, 6)
-        for length, score in final_scores_per_length.items()
-    }
     
     # Prepare base results without hash
     base_results = {
         'config': config_dict,
         'average_rss': avg_rss,
-        'length_scores': rounded_length_scores,
+        'length_scores': length_scores,
         'metadata': metadata
     }
     
@@ -710,5 +703,43 @@ def inspect(
         typer.echo(traceback.format_exc())
         raise typer.Exit(code=1)
 
+@app.command()
+def verify(
+    pt_path: str = typer.Option(...,"--pt-path", help="Path to the .pt probe matrix file"),
+    json_path: str = typer.Option(...,"--json-path", help="Path to the .json results file")
+):
+    """Verify metadata consistency between .pt and .json files."""
+    import torch
+    import json
+
+    try:
+        # Load .pt file
+        pt_data = torch.load(pt_path, map_location='cpu')
+        pt_metadata = pt_data['metadata']
+
+        # Load .json file
+        with open(json_path, 'r', encoding='utf-8') as f:
+            json_data = json.load(f)
+            json_metadata = json_data['metadata']
+
+        # Compare metadata
+        if pt_metadata == json_metadata:
+            typer.echo("✅ Metadata verification: SUCCESS - Files are consistent.")
+        else:
+            typer.echo("❌ Metadata verification: FAILED - Files are inconsistent.")
+            typer.echo("Debug: Check the differences manually.")
+
+    except FileNotFoundError as e:
+        typer.echo(f"❌ Error: File not found - {str(e)}")
+        raise typer.Exit(code=1)
+    except KeyError as e:
+        typer.echo(f"❌ Error: Missing 'metadata' key in file - {str(e)}")
+        raise typer.Exit(code=1)
+    except Exception as e:
+        typer.echo(f"❌ Error: {str(e)}")
+        raise typer.Exit(code=1)
+
+
+
 if __name__ == "__main__":
     app()
\ No newline at end of file
